# coding: utf-8

"""
    authentik

    Making authentication simple.

    The version of the OpenAPI document: 2025.10.0-rc1
    Contact: hello@goauthentik.io
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from authentik_client.models.paginated_flow_stage_binding_list import PaginatedFlowStageBindingList

class TestPaginatedFlowStageBindingList(unittest.TestCase):
    """PaginatedFlowStageBindingList unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> PaginatedFlowStageBindingList:
        """Test PaginatedFlowStageBindingList
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `PaginatedFlowStageBindingList`
        """
        model = PaginatedFlowStageBindingList()
        if include_optional:
            return PaginatedFlowStageBindingList(
                pagination = authentik_client.models.pagination.Pagination(
                    next = 1.337, 
                    previous = 1.337, 
                    count = 1.337, 
                    current = 1.337, 
                    total_pages = 1.337, 
                    start_index = 1.337, 
                    end_index = 1.337, ),
                results = [
                    authentik_client.models.flow_stage_binding.FlowStageBinding(
                        pk = '', 
                        policybindingmodel_ptr_id = '', 
                        target = '', 
                        stage = '', 
                        stage_obj = null, 
                        evaluate_on_plan = True, 
                        re_evaluate_policies = True, 
                        order = -2147483648, 
                        policy_engine_mode = 'all', 
                        invalid_response_action = null, )
                    ],
                autocomplete = {
                    'key' : null
                    }
            )
        else:
            return PaginatedFlowStageBindingList(
                pagination = authentik_client.models.pagination.Pagination(
                    next = 1.337, 
                    previous = 1.337, 
                    count = 1.337, 
                    current = 1.337, 
                    total_pages = 1.337, 
                    start_index = 1.337, 
                    end_index = 1.337, ),
                results = [
                    authentik_client.models.flow_stage_binding.FlowStageBinding(
                        pk = '', 
                        policybindingmodel_ptr_id = '', 
                        target = '', 
                        stage = '', 
                        stage_obj = null, 
                        evaluate_on_plan = True, 
                        re_evaluate_policies = True, 
                        order = -2147483648, 
                        policy_engine_mode = 'all', 
                        invalid_response_action = null, )
                    ],
                autocomplete = {
                    'key' : null
                    },
        )
        """

    def testPaginatedFlowStageBindingList(self):
        """Test PaginatedFlowStageBindingList"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
